<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../src/clipboard.cpp" line="79"/>
        <source>Copy color %1 to clipboard</source>
        <translation>Цвет %1 скопирован в буфер обмена</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Deepin Picker is a quick and easy screen color picking tool. RGB and HEX codes are obtained on click and auto saved to the clipboard.</source>
        <translation>Deepin Picker - это инструмент для быстрого выбора цвета экрана. Коды RGB и HEX получаются по клику и автоматически сохраняются в буфер обмена.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="80"/>
        <source>Deepin Picker</source>
        <translation>Сборщик Цветовых Кодов Deepin</translation>
    </message>
</context>
</TS>
